@@ -10,7 +10,7 @@ from ugrid.py_structures import UGridContacts, UGridMesh1D, UGridMesh2D, UGridNe
 
 def decode_byte_vector_to_string(byte_vector: bytes, ncolumns: int) -> str:
     """From byte vector to string"""
-    return byte_vector[:ncolumns].decode("UTF-8").strip()
+    return byte_vector[:ncolumns].decode("ASCII").strip()
 
 
 def decode_byte_vector_to_list_of_strings(
@@ -18,7 +18,7 @@ def decode_byte_vector_to_list_of_strings(
 ) -> list:
     """From byte vector to a vector of strings"""
     return [
-        byte_vector[str_size * r : str_size * (r + 1)].decode("UTF-8").strip()
+        byte_vector[str_size * r : str_size * (r + 1)].decode("ASCII").strip()
         for r in range(nrows)
     ]
 
@@ -99,7 +99,7 @@ class CUGridNetwork1D(Structure):
             CMesh2d: The created CMesh2d instance.
         """
 
-        name_padded = ugrid_network1D.name.ljust(name_size)
+        name_padded = ugrid_network1D.name.ljust(name_long_size)
 
         node_name_id = pad_and_join_list_of_strings(
             ugrid_network1D.node_name_id, name_size
@@ -118,11 +118,11 @@ class CUGridNetwork1D(Structure):
         c_ugrid_network = CUGridNetwork1D()
 
         # Set the pointers
-        c_ugrid_network.name = c_char_p(name_padded.encode("utf-8"))
+        c_ugrid_network.name = c_char_p(name_padded.encode("ASCII"))
         c_ugrid_network.node_x = numpy_array_to_ctypes(ugrid_network1D.node_x)
         c_ugrid_network.node_y = numpy_array_to_ctypes(ugrid_network1D.node_y)
-        c_ugrid_network.node_name_id = c_char_p(node_name_id.encode("utf-8"))
-        c_ugrid_network.node_name_long = c_char_p(node_name_long.encode("utf-8"))
+        c_ugrid_network.node_name_id = c_char_p(node_name_id.encode("ASCII"))
+        c_ugrid_network.node_name_long = c_char_p(node_name_long.encode("ASCII"))
         c_ugrid_network.branch_node = numpy_array_to_ctypes(ugrid_network1D.branch_node)
         c_ugrid_network.branch_length = numpy_array_to_ctypes(
             ugrid_network1D.branch_length
@@ -130,8 +130,8 @@ class CUGridNetwork1D(Structure):
         c_ugrid_network.branch_order = numpy_array_to_ctypes(
             ugrid_network1D.branch_order
         )
-        c_ugrid_network.branch_name_id = c_char_p(branch_name_id.encode("utf-8"))
-        c_ugrid_network.branch_name_long = c_char_p(branch_name_long.encode("utf-8"))
+        c_ugrid_network.branch_name_id = c_char_p(branch_name_id.encode("ASCII"))
+        c_ugrid_network.branch_name_long = c_char_p(branch_name_long.encode("ASCII"))
         c_ugrid_network.geometry_nodes_x = numpy_array_to_ctypes(
             ugrid_network1D.geometry_nodes_x
         )
@@ -153,11 +153,15 @@ class CUGridNetwork1D(Structure):
         The pointers are then set to the freshly allocated memory.
         The memory is owned by the Network1D instance which is returned by this method.
 
+        Args:
+            name_size (int): The size of the names.
+            name_long_size (int): The size of the long names.
+
         Returns:
             UGridNetwork1D: The object owning the allocated memory.
         """
 
-        name = " " * name_size
+        name = " " * name_long_size
         node_x = np.empty(self.num_nodes, dtype=np.double)
         node_y = np.empty(self.num_nodes, dtype=np.double)
         node_name_id = " " * self.num_nodes * name_size
@@ -171,16 +175,16 @@ class CUGridNetwork1D(Structure):
         geometry_nodes_y = np.empty(self.num_geometry_nodes, dtype=np.double)
         num_branch_geometry_nodes = np.empty(self.num_branches, dtype=np.int)
 
-        self.name = c_char_p(name.encode("utf-8"))
+        self.name = c_char_p(name.encode("ASCII"))
         self.node_x = numpy_array_to_ctypes(node_x)
         self.node_y = numpy_array_to_ctypes(node_y)
-        self.node_name_id = c_char_p(node_name_id.encode("utf-8"))
-        self.node_name_long = c_char_p(node_name_long.encode("utf-8"))
+        self.node_name_id = c_char_p(node_name_id.encode("ASCII"))
+        self.node_name_long = c_char_p(node_name_long.encode("ASCII"))
         self.branch_node = numpy_array_to_ctypes(branch_node)
         self.branch_length = numpy_array_to_ctypes(branch_length)
         self.branch_order = numpy_array_to_ctypes(branch_order)
-        self.branch_name_id = c_char_p(branch_name_id.encode("utf-8"))
-        self.branch_name_long = c_char_p(branch_name_long.encode("utf-8"))
+        self.branch_name_id = c_char_p(branch_name_id.encode("ASCII"))
+        self.branch_name_long = c_char_p(branch_name_long.encode("ASCII"))
         self.geometry_nodes_x = numpy_array_to_ctypes(geometry_nodes_x)
         self.geometry_nodes_y = numpy_array_to_ctypes(geometry_nodes_y)
         self.num_branch_geometry_nodes = numpy_array_to_ctypes(
@@ -257,6 +261,8 @@ class CUGridMesh1D(Structure):
         """Creates a new CMesh instance from a given Mesh2d instance.
 
         Args:
+            name_size (int): The size of the names.
+            name_long_size (int): The size of the long names.
             mesh1d (UGridMesh1D): Class of numpy instances owning the state.
 
         Returns:
@@ -266,22 +272,22 @@ class CUGridMesh1D(Structure):
         c_mesh1d = CUGridMesh1D()
 
         # Set the pointers
-        mesh1d_name_padded = mesh1d.name.ljust(name_size)
-        network1d_name_padded = mesh1d.network_name.ljust(name_size)
+        mesh1d_name_padded = mesh1d.name.ljust(name_long_size)
+        network1d_name_padded = mesh1d.network_name.ljust(name_long_size)
         node_name_id = pad_and_join_list_of_strings(mesh1d.node_name_id, name_size)
         node_name_long = pad_and_join_list_of_strings(
             mesh1d.node_name_long, name_long_size
         )
 
-        c_mesh1d.name = c_char_p(mesh1d_name_padded.encode("utf-8"))
-        c_mesh1d.network_name = c_char_p(network1d_name_padded.encode("utf-8"))
+        c_mesh1d.name = c_char_p(mesh1d_name_padded.encode("ASCII"))
+        c_mesh1d.network_name = c_char_p(network1d_name_padded.encode("ASCII"))
         c_mesh1d.node_x = numpy_array_to_ctypes(mesh1d.node_x)
         c_mesh1d.node_y = numpy_array_to_ctypes(mesh1d.node_y)
         c_mesh1d.edge_node = numpy_array_to_ctypes(mesh1d.edge_node)
         c_mesh1d.branch_id = numpy_array_to_ctypes(mesh1d.branch_id)
         c_mesh1d.branch_offset = numpy_array_to_ctypes(mesh1d.branch_offset)
-        c_mesh1d.node_name_id = c_char_p(node_name_id.encode("utf-8"))
-        c_mesh1d.node_name_long = c_char_p(node_name_long.encode("utf-8"))
+        c_mesh1d.node_name_id = c_char_p(node_name_id.encode("ASCII"))
+        c_mesh1d.node_name_long = c_char_p(node_name_long.encode("ASCII"))
         c_mesh1d.edge_edge_id = numpy_array_to_ctypes(mesh1d.edge_edge_id)
         c_mesh1d.edge_edge_offset = numpy_array_to_ctypes(mesh1d.edge_edge_offset)
         c_mesh1d.edge_x = numpy_array_to_ctypes(mesh1d.edge_x)
@@ -302,12 +308,16 @@ class CUGridMesh1D(Structure):
         The pointers are then set to the freshly allocated memory.
         The memory is owned by the Mesh1d instance which is returned by this method.
 
+        Args:
+            name_size (int): The size of the names.
+            name_long_size (int): The size of the long names.
+
         Returns:
             UGridMesh1D: The object owning the allocated memory.
         """
 
-        name = " " * name_size
-        network_name = " " * name_size
+        name = " " * name_long_size
+        network_name = " " * name_long_size
         node_x = np.empty(self.num_nodes, dtype=np.double)
         node_y = np.empty(self.num_nodes, dtype=np.double)
         edge_node = np.empty(self.num_edges * 2, dtype=np.int)
@@ -320,15 +330,15 @@ class CUGridMesh1D(Structure):
         edge_x = np.empty(self.num_edges, dtype=np.double)
         edge_y = np.empty(self.num_edges, dtype=np.double)
 
-        self.name = c_char_p(name.encode("utf-8"))
-        self.network_name = c_char_p(network_name.encode("utf-8"))
+        self.name = c_char_p(name.encode("ASCII"))
+        self.network_name = c_char_p(network_name.encode("ASCII"))
         self.node_x = numpy_array_to_ctypes(node_x)
         self.node_y = numpy_array_to_ctypes(node_y)
         self.edge_node = numpy_array_to_ctypes(edge_node)
         self.branch_id = numpy_array_to_ctypes(branch_id)
         self.branch_offset = numpy_array_to_ctypes(branch_offset)
-        self.node_name_id = c_char_p(node_name_id.encode("utf-8"))
-        self.node_name_long = c_char_p(node_name_long.encode("utf-8"))
+        self.node_name_id = c_char_p(node_name_id.encode("ASCII"))
+        self.node_name_long = c_char_p(node_name_long.encode("ASCII"))
         self.edge_edge_id = numpy_array_to_ctypes(edge_edge_id)
         self.edge_edge_offset = numpy_array_to_ctypes(edge_edge_offset)
         self.edge_x = numpy_array_to_ctypes(edge_x)
@@ -421,11 +431,12 @@ class CUGridMesh2D(Structure):
     ]
 
     @staticmethod
-    def from_py_structure(mesh2d: UGridMesh2D, name_size: int) -> CUGridMesh2D:
+    def from_py_structure(mesh2d: UGridMesh2D, name_long_size: int) -> CUGridMesh2D:
         """Creates a new CMesh instance from a given Mesh2d instance.
 
         Args:
             mesh2d (UGridMesh2D): Class of numpy instances owning the state.
+            name_long_size (int): The size of the long names.
 
         Returns:
             CMesh2d: The created CMesh2d instance.
@@ -434,8 +445,8 @@ class CUGridMesh2D(Structure):
         c_mesh2d = CUGridMesh2D()
 
         # Required arrays
-        mesh2d_name_padded = mesh2d.name.ljust(name_size)
-        c_mesh2d.name = c_char_p(mesh2d_name_padded.encode("utf-8"))
+        mesh2d_name_padded = mesh2d.name.ljust(name_long_size)
+        c_mesh2d.name = c_char_p(mesh2d_name_padded.encode("ASCII"))
         c_mesh2d.edge_node = numpy_array_to_ctypes(mesh2d.edge_node)
         c_mesh2d.node_x = numpy_array_to_ctypes(mesh2d.node_x)
         c_mesh2d.node_y = numpy_array_to_ctypes(mesh2d.node_y)
@@ -476,16 +487,19 @@ class CUGridMesh2D(Structure):
 
         return c_mesh2d
 
-    def allocate_memory(self, name_size: int) -> UGridMesh2D:
+    def allocate_memory(self, name_long_size: int) -> UGridMesh2D:
         """Allocate data according to the parameters with the "num_" prefix.
         The pointers are then set to the freshly allocated memory.
         The memory is owned by the Mesh2D instance which is returned by this method.
 
+        Args:
+            name_long_size (int): The size of the long names.
+
         Returns:
             UGridMesh2D: The object owning the allocated memory.
         """
 
-        name = " " * name_size
+        name = " " * name_long_size
         node_x = np.empty(self.num_nodes, dtype=np.double)
         node_y = np.empty(self.num_nodes, dtype=np.double)
         edge_node = np.empty(self.num_edges * 2, dtype=np.int)
@@ -507,7 +521,7 @@ class CUGridMesh2D(Structure):
         boundary_node_connectivity = np.empty(self.num_nodes, dtype=np.double)
         volume_coordinates = np.empty(self.num_faces, dtype=np.int)
 
-        self.name = c_char_p(name.encode("utf-8"))
+        self.name = c_char_p(name.encode("ASCII"))
         self.edge_node = numpy_array_to_ctypes(edge_node)
         self.face_node = numpy_array_to_ctypes(face_node)
         self.node_x = numpy_array_to_ctypes(node_x)
@@ -608,9 +622,9 @@ class CUGridContacts(Structure):
         c_contacts = CUGridContacts()
 
         # Set the pointers
-        contacts_name_padded = contacts.name.ljust(name_size)
-        mesh_from_name_padded = contacts.mesh_from_name.ljust(name_size)
-        mesh_to_name_padded = contacts.mesh_to_name.ljust(name_size)
+        contacts_name_padded = contacts.name.ljust(name_long_size)
+        mesh_from_name_padded = contacts.mesh_from_name.ljust(name_long_size)
+        mesh_to_name_padded = contacts.mesh_to_name.ljust(name_long_size)
 
         contact_name_id_padded = pad_and_join_list_of_strings(
             contacts.contact_name_id, name_size
@@ -619,14 +633,14 @@ class CUGridContacts(Structure):
             contacts.contact_name_long, name_long_size
         )
 
-        c_contacts.name = c_char_p(contacts_name_padded.encode("utf-8"))
+        c_contacts.name = c_char_p(contacts_name_padded.encode("ASCII"))
         c_contacts.edges = numpy_array_to_ctypes(contacts.edges)
         c_contacts.contact_type = numpy_array_to_ctypes(contacts.contact_type)
-        c_contacts.mesh_from_name = c_char_p(mesh_from_name_padded.encode("utf-8"))
-        c_contacts.mesh_to_name = c_char_p(mesh_to_name_padded.encode("utf-8"))
-        c_contacts.contact_name_id = c_char_p(contact_name_id_padded.encode("utf-8"))
+        c_contacts.mesh_from_name = c_char_p(mesh_from_name_padded.encode("ASCII"))
+        c_contacts.mesh_to_name = c_char_p(mesh_to_name_padded.encode("ASCII"))
+        c_contacts.contact_name_id = c_char_p(contact_name_id_padded.encode("ASCII"))
         c_contacts.contact_name_long = c_char_p(
-            contact_name_long_padded.encode("utf-8")
+            contact_name_long_padded.encode("ASCII")
         )
         c_contacts.mesh_from_location = contacts.mesh_from_location
         c_contacts.mesh_to_location = contacts.mesh_to_location
@@ -641,25 +655,28 @@ class CUGridContacts(Structure):
         The pointers are then set to the freshly allocated memory.
         The memory is owned by the Contacts instance which is returned by this method.
 
+        Args:
+            name_long_size (int): The size of the long names.
+
         Returns:
             UGridContacts: The object owning the allocated memory.
         """
 
-        name = " " * name_size
+        name = " " * name_long_size
+        mesh_from_name = " " * name_long_size
+        mesh_to_name = " " * name_long_size
         edges = np.empty(self.num_contacts * 2, dtype=np.int)
-        mesh_from_name = " " * name_size
-        mesh_to_name = " " * name_size
         contact_type = np.empty(self.num_contacts, dtype=np.int)
         contact_name_id = " " * self.num_contacts * name_size
         contact_name_long = " " * self.num_contacts * name_long_size
 
-        self.name = c_char_p(name.encode("utf-8"))
+        self.name = c_char_p(name.encode("ASCII"))
         self.edges = numpy_array_to_ctypes(edges)
         self.contact_type = numpy_array_to_ctypes(contact_type)
-        self.contact_name_id = c_char_p(contact_name_id.encode("utf-8"))
-        self.contact_name_long = c_char_p(contact_name_long.encode("utf-8"))
-        self.mesh_from_name = c_char_p(mesh_from_name.encode("utf-8"))
-        self.mesh_to_name = c_char_p(mesh_to_name.encode("utf-8"))
+        self.contact_name_id = c_char_p(contact_name_id.encode("ASCII"))
+        self.contact_name_long = c_char_p(contact_name_long.encode("ASCII"))
+        self.mesh_from_name = c_char_p(mesh_from_name.encode("ASCII"))
+        self.mesh_to_name = c_char_p(mesh_to_name.encode("ASCII"))
 
         return UGridContacts(
             name=name,
